@@ -46,7 +46,7 @@
 
 QT_BEGIN_NAMESPACE
 
-class QQuickExclusiveGroup;
+class QQuickExclusiveGroup1;
 
 class QQuickAction : public QObject
 {
@@ -61,7 +61,7 @@ class QQuickAction : public QObject
     Q_PROPERTY(bool checkable READ isCheckable WRITE setCheckable NOTIFY checkableChanged)
     Q_PROPERTY(bool checked READ isChecked WRITE setChecked DESIGNABLE isCheckable NOTIFY toggled)
 
-    Q_PROPERTY(QQuickExclusiveGroup *exclusiveGroup READ exclusiveGroup WRITE setExclusiveGroup NOTIFY exclusiveGroupChanged)
+    Q_PROPERTY(QQuickExclusiveGroup1 *exclusiveGroup READ exclusiveGroup WRITE setExclusiveGroup NOTIFY exclusiveGroupChanged)
 #ifndef QT_NO_SHORTCUT
     Q_PROPERTY(QVariant shortcut READ shortcut WRITE setShortcut NOTIFY shortcutChanged)
 #endif
@@ -99,12 +99,12 @@ public:
     bool isChecked() const { return m_checkable && m_checked; }
     void setChecked(bool c);
 
-    QQuickExclusiveGroup *exclusiveGroup() const;
-    void setExclusiveGroup(QQuickExclusiveGroup *arg);
+    QQuickExclusiveGroup1 *exclusiveGroup() const;
+    void setExclusiveGroup(QQuickExclusiveGroup1 *arg);
 
     QIcon icon() const { return m_icon; }
     QVariant iconVariant() const { return QVariant(m_icon); }
-    void setIcon(QIcon icon) { m_icon = icon; emit iconChanged(); }
+    void setIcon(const QIcon &icon) { m_icon = icon; emit iconChanged(); }
 
     bool event(QEvent *e);
 
@@ -116,12 +116,12 @@ Q_SIGNALS:
     void toggled(bool checked);
 
     void textChanged();
-    void shortcutChanged(QVariant shortcut);
+    void shortcutChanged(const QVariant &shortcut);
 
     void iconChanged();
     void iconNameChanged();
     void iconSourceChanged();
-    void tooltipChanged(QString arg);
+    void tooltipChanged(const QString &arg);
     void enabledChanged();
     void checkableChanged();
 
@@ -135,7 +135,7 @@ private:
     bool m_enabled;
     bool m_checkable;
     bool m_checked;
-    QPointer<QQuickExclusiveGroup> m_exclusiveGroup;
+    QPointer<QQuickExclusiveGroup1> m_exclusiveGroup;
     QKeySequence m_shortcut;
     QKeySequence m_mnemonic;
     QString m_tooltip;
